#
# spec file for package libp11
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# the libname depends on what version openssl it is linked against
%if 0%{?suse_version} < 1500
# libp11.so.2 for openssl 1.0 - suse_version < 1500
%define libname libp11-2
%else
# libp11.so.3 for openssl 1.1 - suse_version >= 1500
%define libname libp11-3
%endif
Name:           libp11
Version:        0.4.7
Release:        lp151.3.3
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
License:        LGPL-2.1+
Group:          Productivity/Security
Url:            https://github.com/OpenSC/libp11
Source0:        https://github.com/OpenSC/libp11/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/OpenSC/libp11/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package -n %{libname}
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Productivity/Security

%description -n %{libname}
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package -n openssl-engine-%{name}
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Productivity/Security

%description -n openssl-engine-%{name}
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package devel
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       openssl-devel

%description devel
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code include the official header files (version 2.20) and
thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%prep
%setup -q
# Since the library name changes based on used openssl, we have to create baselibs.conf dynamically
echo %{libname} > %{_sourcedir}/baselibs.conf 

%build
%configure \
  --disable-static \
  --disable-silent-rules \
	--enable-doc\
	--docdir=%{_docdir}/%{libname}
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/%{name} %{buildroot}%{_docdir}/%{libname}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_docdir}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc %{_docdir}/%{libname}
%{_libdir}/*.so.*

%files -n openssl-engine-%{name}
%if 0%{?suse_version} > 1325
%{_libdir}/engines-?.?
%else
%{_libdir}/engines
%endif

%files devel
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Jan 17 2018 dimstar@opensuse.org
- Conditionalize libname to libp11-2 for suse_version < 1500 (using
  openssl 1.0) / libp11-3 for suse_version >= 1500 (using
  openssl 1.1).
- Create baselibs.conf dynamically, since the library name can be
  different. Drop the static baselibs.conf.
* Wed Jul 19 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs.
* Mon Jul 17 2017 tchvatal@suse.com
- Version update to 0.4.7:
  * Added OpenSSL-style engine error reporting (Michał Trojnara)
  * Added the FORCE_LOGIN engine ctrl command (Michał Trojnara)
  * Implemented the QUIET engine ctrl command (Michał Trojnara)
  * Modified CKU_CONTEXT_SPECIFIC PIN requests to be based
    on the CKA_ALWAYS_AUTHENTICATE attribute rather than the
    CKR_USER_NOT_LOGGED_IN error (Michał Trojnara)
  * Fixed printing hex values (Michał Trojnara)
  * Fixed build error with OPENSSL_NO_EC (Kai Kang)
* Fri Jun 23 2017 mpluskal@suse.com
- Update to verion 0.4.6
  * For full list of changes since version 0.3.0 see NEWS
- Create openssl-engine-libp11 subpackage
- Add gpg signature
* Wed Dec  2 2015 p.drouand@gmail.com
- Update to version 0.3.0
  * Added small test suite based on softhsm (run on make check)
  * Memory leak fixes
  * On module initialization tell the module that the OS locking
    primitives are OK to use
  * Transparently handle applications that fork. That is call C_Initialize()
    and reopen any handles if a fork is detected.
  * Eliminated any hard coded limits for certificate size
  * Added support for ECDSA
  * Allow RSA_NO_PADDING padding mode in PKCS11_private_encrypt
  * Eliminated several hard-coded limits in parameter sizes.
- Update project and download Urls
* Tue Sep 25 2012 sbrabec@suse.cz
- Update to version 0.2.8:
  * Bumped soname for PKCS11_token struct size changes.
  * Display the number of available slots.
  * Expose more token flags in PKCS11_token structure.
  * Check that private data is not NULL in pkcs11_release_slot.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jan 11 2011 sbrabec@suse.cz
-  Updated to version 0.2.7:
  * Ignore CKR_CRYPTOKI_ALREADY_INITIALIZED while initializing.
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.2.6:
  * Add new symbol to export file.
  * Add function to export the slot id.
  * Increase library version because of the new function.
* Wed Apr  8 2009 sbrabec@suse.cz
- Don't call autoreconf on older products.
* Tue Sep  2 2008 sbrabec@suse.cz
- Call autoreconf to build correctly with new libtool.
* Tue Sep  2 2008 crrodriguez@suse.de
- fix build, doxygen required.
- kill ".la" files and static libraries
- fix -devel package requires
* Tue Aug 19 2008 sbrabec@suse.cz
- Updated to version 0.2.4:
  * Build system rewritten
  * added PKCS11_CTX_init_args
  * fix segfault in init_args code
  * implemented PKCS11_private_encrypt
- Fixed incorrect API.
- Fixed x86_64 issues.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sun Jul 29 2007 ro@suse.de
- provide old name
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.2.3:
  * update wiki export script.
  * replaced rsa header files from rsalabs (official) with scute
    (open source).
  * allow CKR_USER_ALREADY_LOGGED_IN on C_Login.
  * mark internal functions as static.
  * add code to store public keys and generate keys.
- Name package according to shared library packaging policy.
* Thu Mar 29 2007 ro@suse.de
- added zlib-devel to buildreq
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.2.2:
  * bug fixes
  * code cleanup
* Fri May 12 2006 sbrabec@suse.cz
- New SuSE package, version 0.2.1.
